@@ -1,8 +1,7 @@
 from __future__ import annotations
 
 import sys
-import string
-from typing import IO, TYPE_CHECKING, Any, Sequence
+from typing import IO, TYPE_CHECKING, Any, Callable, Sequence
 from pathlib import Path
 from gettext import gettext as _
 from argparse import (
@@ -17,6 +16,7 @@ from simpleconf import Config
 
 from . import type_
 from .utils import (
+    format_title,
     get_ns_dest,
     import_pyfile,
     add_attribute,
@@ -34,6 +34,7 @@ from .action import (
     ClearAppendAction,
     ClearExtendAction,
     NamespaceAction,
+    SubParserAction,
     HelpAction,
 )
 from .formatter import ChargedHelpFormatter
@@ -62,6 +63,7 @@ class ArgumentParser(APArgumentParser):
         allow_abbrev: bool = True,
         exit_on_error: bool = True,
         exit_on_void: bool = False,
+        pre_parse: Callable[[ArgumentParser], None] | None = None,
     ) -> None:
         old_add_help = add_help
         add_help = False
@@ -84,6 +86,7 @@ class ArgumentParser(APArgumentParser):
         super().__init__(**kwargs)
 
         self.exit_on_void = exit_on_void
+        self.pre_parse = pre_parse
         self._subparsers_action = None
 
         # Register our actions to override argparse's or add new ones
@@ -100,6 +103,7 @@ class ArgumentParser(APArgumentParser):
         self.register("action", "clear_extend", ClearExtendAction)
         self.register("action", "ns", NamespaceAction)
         self.register("action", "namespace", NamespaceAction)
+        self.register("action", "parsers", SubParserAction)
         self.register("action", "help", HelpAction)
         self.register("type", "py", type_.py)
         self.register("type", "json", type_.json)
@@ -152,6 +156,9 @@ class ArgumentParser(APArgumentParser):
         if self._subparsers is not self._positionals:
             self._subparsers.order = order
 
+        # Add parent to subparsers action
+        # So that subparsers.add_parser add parent to the sub-parser
+        action.parent = self
         return action
 
     def add_subparser(self, name: str, **kwargs) -> ArgumentParser | Any:
@@ -211,6 +218,15 @@ class ArgumentParser(APArgumentParser):
             # make sure that args are mutable
             args = list(args)
 
+        # default Namespace built from parser defaults
+        if namespace is None:
+            namespace = Namespace()
+
+        if callable(self.pre_parse):
+            new_args = self.pre_parse(self, args, namespace)
+            if new_args is not None:
+                args = new_args
+
         if not self.fromfile_prefix_chars:
             new_args = args
         else:
@@ -232,10 +248,6 @@ class ArgumentParser(APArgumentParser):
                     except Exception as e:
                         self.error(f"Cannot import [{conf}]: {e}")
 
-        # default Namespace built from parser defaults
-        if namespace is None:
-            namespace = Namespace()
-
         # add any action defaults that aren't present
         # Do this mainly for namespace actions, like "--group.abc"
         for action in self._actions:
@@ -414,9 +426,10 @@ class ArgumentParser(APArgumentParser):
                     # hide them in usage as well
                     action.help = SUPPRESS
                 continue
+
             formatter.start_section(
                 "\033[1m\033[4m"
-                f"{string.capwords(action_group.title)}"
+                f"{format_title(action_group.title)}"
                 "\033[0m\033[0m"
             )
             formatter.add_text(action_group.description)
